@@ -4,17 +4,32 @@ $VERSION = "0.1";
 use strict;
 use base qw/OurNet::BBS::MAPLE3::Article/;
 use fields qw/_cache/;
-use subs qw/STORE/;
+use subs qw/STORE readok writeok/;
 
 BEGIN {__PACKAGE__->initvars()};
 
+sub writeok {
+    my ($self, $user, $op) = @_;
+
+    return if $op eq 'DELETE';
+
+    # in melix, only sysop could modify an article
+    return ($user->has_perm('PERM_SYSOP'));
+
+}
+
+# well, since you're here...
+sub readok { 1 }
+
 sub STORE {
     my ($self, $key, $value) = @_;
     $self->refresh_meta($key);
 
     if ($key eq 'body') {
-        my $file = join('/', $self->basedir, substr($self->{name}, -1), $self->{name});
-        unless (-s $file or substr($value, 0, 6) eq '@: ') {
+        my $file = join(
+	    '/', $self->basedir, substr($self->{name}, -1), $self->{name}
+	);
+        unless (-s $file) {
             my $hdr = $self->{_cache}{header};
             my $temp;
 
@@ -30,9 +45,17 @@ sub STORE {
 
             $value = "$temp\n$value" if $temp;
         }
+
         open _, ">$file" or die "cannot open $file";
+
+	if ($^O eq 'MSWin32') {
+	    binmode(_); # turn off crlf conversion
+	    $value =~ s/\n/\012/g;
+	}
+
         print _ $value;
         close _;
+
         $self->{btime} = (stat($file))[9];
         $self->{_cache}{$key} = $value;
     }
