@@ -1,5 +1,5 @@
 package OurNet::BBS::NNTP::Board;
-$VERSION = "0.1";
+$VERSION = '0.1';
 
 use strict;
 use base qw/OurNet::BBS::Base/;
@@ -14,11 +14,11 @@ BEGIN {
 sub refresh_articles {
     my $self = shift;
 
-    return $self->{_cache}{articles} ||= $self->module('ArticleGroup')->new
-	({
-	  nntp		=> $self->{nntp},
-	  groupname	=> $self->{groupname},
-	 });
+    return $self->{_cache}{articles} ||=
+	$self->module('ArticleGroup')->new({
+	    nntp	=> $self->{nntp},
+	    groupname	=> $self->{groupname},
+	});
 }
 
 sub refresh_archives {
@@ -29,14 +29,10 @@ sub refresh_meta {
     my ($self, $key) = @_;
 
     # XXX: no meta-data yet
-    @{$self->{_cache}}{@packlist} = () if 0;
+    # @{$self->{_cache}}{@packlist} = ();
 
     return 1;
 }
 
-sub STORE {
-    die 'no Board STORE';
-}
-
 1;
 
